#include "editingTableMask.h"
#include <QSqlRelationalDelegate>
#include <QLabel>
#include <QSqlRelationalTableModel>
#include <QComboBox>
#include <QPushButton>
#include <QGridLayout>
#include <QLineEdit>

editingTableMask::editingTableMask(QAbstractItemModel* model, int pos, QWidget *parent):
    QWidget(parent)
{
    m_model = model;
    m_mapper = new QDataWidgetMapper(this);
    m_mapper->setSubmitPolicy(QDataWidgetMapper::ManualSubmit);
    m_mapper->setModel(model);
    m_mapper->setItemDelegate(new QSqlRelationalDelegate(this));


    QGridLayout *layout = new QGridLayout(this);
    int i;
    for (i = 0; i<model->columnCount(); i++)
    {
        QWidget *displayText = insertLabelField(i);
        QWidget *editingField = insertEditingField(i);
        layout->addWidget(displayText,i,0,1,-1);
        layout->addWidget(editingField,i,1,1,-1);
        m_mapper->addMapping(editingField,i);
    }
    m_mapper->setCurrentIndex(pos);
    QPushButton *btnOk, *btnClose;
    btnOk = new QPushButton("Ok",this);
    btnClose = new QPushButton("Close",this);
    connect(btnClose,SIGNAL(clicked()),this,SIGNAL(closed()));
    connect(btnOk,SIGNAL(clicked()),SLOT(OKPressed()));
    layout->addWidget(btnOk,i,0);
    layout->addWidget(btnClose,i,1);
}

editingTableMask::~editingTableMask()
{
    delete m_mapper;
}

QWidget* editingTableMask::insertLabelField(const int nColumn)
{
    QLabel *label = new QLabel(this);
    label->setText(m_model->headerData(nColumn,Qt::Horizontal).toString());

    return label;
}

QWidget* editingTableMask::insertEditingField(const int nColumn)
{
    Q_UNUSED(nColumn);
    QSqlRelationalTableModel *_model;
    _model = qobject_cast<QSqlRelationalTableModel*>(m_model);
    Q_ASSERT(_model != 0);

    QSqlRelation relation = _model->relation(nColumn);

    if (relation.isValid()) {
        QComboBox *combo = new QComboBox(this);
        combo->setModel(_model->relationModel(nColumn));
        combo->setModelColumn(_model->relationModel(nColumn)->fieldIndex(relation.displayColumn()));
        combo->insertItem(0,"");
        combo->setCurrentIndex(0);
        return combo;
    } else {
        QLineEdit *textEdit = new QLineEdit(this);
        return textEdit;
    }
}

void editingTableMask::OKPressed()
{
    m_mapper->submit();
    emit accepted();
}
