#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "editingTableMask.h"
#include <QSqlDatabase>
#include <QSqlRelationalTableModel>
#include <QDebug>
#include <QDialog>
#include <QSqlQuery>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    connect(ui->btnSave,SIGNAL(clicked()),this,SLOT(save()));
    connect(ui->btnClose,SIGNAL(clicked()),this,SLOT(close()));
#ifdef UPOSTGRES
    QSqlDatabase db = QSqlDatabase::addDatabase("QPSQL");
    db.setHostName("localhost");
    db.setDatabaseName("helpme");
    db.setUserName("postgres");
    db.setPassword("postgres");
    bool ok = db.open();
#else // UPOSTGRES
    QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName(":memory:");
    bool ok = db.open();

    QSqlQuery query;
    query.exec("create table address (id int primary key, name varchar(128), city_id int)");
    query.exec("create table city (id int primary key, name varchar(128))");
    query.exec("INSERT INTO city(id, name) VALUES(1,'Madrid')");
    query.exec("INSERT INTO city(id, name) VALUES(2,'Rome')");
    query.exec("INSERT INTO city(id, name) VALUES(3,'Paris')");

    query.exec("INSERT INTO address(id,name,city_id) VALUES(5,'Me',2)");
    query.exec("INSERT INTO address(id,name,city_id) VALUES(6,'You',1)");
    query.exec("INSERT INTO address(id,name,city_id) VALUES(7,'Him',3)");
#endif

    if (!ok)
        qDebug() << "Connection not opened";

    QSqlRelationalTableModel *model = new QSqlRelationalTableModel(this,db);
    model->setTable("address");
    model->setRelation(2,QSqlRelation("city","id","name"));
    model->select();

    // LINE VERY DANGEROUS
    model->removeColumn(0);

    ui->tableView->setModel(model);

    connect(ui->tableView,SIGNAL(doubleClicked(QModelIndex)),
            this,SLOT(Edit(QModelIndex)));
}

void MainWindow::Edit(QModelIndex idx)
{
    QAbstractItemModel *localModel = ui->tableView->model();
    editingTableMask* mask = new editingTableMask(localModel,idx.row(), this);

    QDialog *dialogBox = new QDialog(this);
    dialogBox->setWindowTitle(tr("Editing the table"));

    mask->setParent(dialogBox);
    QGridLayout *dialogLayout = new QGridLayout(dialogBox);

    connect(mask,SIGNAL(accepted()),dialogBox,SLOT(accept()));
    connect(mask,SIGNAL(closed()),dialogBox,SLOT(reject()));

    dialogLayout->addWidget(mask);
    dialogBox->setLayout(dialogLayout);

    dialogBox->exec();

    delete dialogBox;

}

void MainWindow::save()
{
    QSqlRelationalTableModel *model;
    model = qobject_cast<QSqlRelationalTableModel*>(ui->tableView->model());
    Q_CHECK_PTR(model);

    model->submitAll();
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
